;+
; NAME: eis_md_decomp.pro
;
; PURPOSE: Decompress EIS mission data packets.
;      
; CATEGORY: Science
;
; CALLING SEQUENCE: eis_mk_decomp, 'md_archive'
;
; INPUTS: Filename string of the mission data archive
;
; KEYWORD PARAMETERS: None
;
; OUTPUTS: One decompressed mission data archive in /tmp
;
; CALLS: Various SSW fits routines.
;
; COMMON BLOCKS:None.
;
; PROCEDURE:
;
; RESTRICTIONS: Uses SolarSoft
;
; MODIFICATION HISTORY:
;	23/11/05 mcrw	wrote
;       14/08/06 mcrw	added documentation
;
;-

pro eis_md_decomp, directory, plan_dates, verbose_level=verbose_level, rescued=rescued, trace=trace

  log_dir = getenv('HOME') + '/Hinode/decompression'
  log_name = log_dir + '/decompression_' + plan_dates + '_log.txt'

  logger = ptr_new(obj_new('eis_logger'))
  print, 'Got logger'

  res = *logger->open_log(log_name, /append)
  print, 'Opened log', res
  
  md_decompressor = obj_new('eis_md_decompressor', logger, plan_dates, verbose_level=verbose_level, rescued=rescued, trace=trace)
;  md_decompressor = obj_new('eis_md_decompressor', plan_dates, verbose_level=verbose_level, rescued=rescued, trace=trace)

  ; md_decompressor->set_verbose, 1
  
  ; Read in decompression factors (a, b, c, Nc)
  ; md_decompressor->read_decompression_factors

  source_directory = directory + path_sep()
  print, 'eis_md_decomp: searching ' + source_directory
  compressed_files = file_search(source_directory + 'eis_md*', count=count)
  if count eq 0 then begin
      print, 'No files'
      md_decompressor->tidy_up
      return
   endif

  md_decompressor->set_compressed_files_count, count
  print, 'eis_md_decomp : decompressing ' + strtrim(string(count), 2) + ' files'
  md_decompressor->log, 'eis_md_decomp : decompressing ' + strtrim(string(count), 2) + ' files'

  md_decompressor->pre_report
  for i = 0, count - 1 do begin
     md_decompressor->reset
     md_decompressor->log, 'Decompressing ' + compressed_files[i] 
     md_decompressor->decompress, compressed_files[i], verbose_level=verbose_level, rescued=rescued
     md_decompressor->update_stats
     md_decompressor->log_report
     md_decompressor->debug
     md_decompressor->clean
  endfor

  md_decompressor->post_report
  md_decompressor->debug
  md_decompressor->tidy_up

;  obj_destroy, md_decompressor
end
